@@ -17,7 +17,7 @@ module RSpec
           actual   = "foo\nbar\nzap\nthis\nis\nsoo\nvery\nvery\nequal\ninsert\na\nline\n"
 
           if Diff::LCS::VERSION.to_f < 1.4 || Diff::LCS::VERSION >= "1.4.4"
-            expected_diff = dedent(<<-'EOD')
+            expected_diff = dedent(<<-"EOD")
               |
               |
               |@@ -1,6 +1,6 @@
@@ -28,7 +28,7 @@ module RSpec
               | this
               | is
               | soo
-              |@@ -9,6 +9,5 @@
+              |@@ #{::Diff::LCS::VERSION.to_f > 1.5 ? "-9,5 +9,4" : "-9,6 +9,5"} @@
               | equal
               | insert
               | a
@@ -66,7 +66,7 @@ module RSpec
           actual   = "foo\nbar\nzap\nthis\nis\nsoo\nvery\nvery\nequal\ninsert\na\nline\n"
 
           if Diff::LCS::VERSION.to_f < 1.4 || Diff::LCS::VERSION >= "1.4.4"
-            expected_diff = dedent(<<-'EOS')
+            expected_diff = dedent(<<-"EOS")
               |
               |
               |@@ -1,6 +1,6 @@
@@ -77,7 +77,7 @@ module RSpec
               | this
               | is
               | soo
-              |@@ -9,6 +9,5 @@
+              |@@ #{::Diff::LCS::VERSION.to_f > 1.5 ? "-9,5 +9,4" : "-9,6 +9,5"} @@
               | equal
               | insert
               | a
@@ -198,9 +198,9 @@ module RSpec
           expected = animal_class.new "bob", "giraffe"
           actual   = animal_class.new "bob", "tortoise"
 
-          expected_diff = dedent(<<-'EOD')
+          expected_diff = dedent(<<-"EOD")
             |
-            |@@ -1,5 +1,5 @@
+            |@@ #{one_line_header(5)} @@
             | <Animal
             |   name=bob,
             |-  species=tortoise
@@ -217,10 +217,10 @@ module RSpec
           expected = [ :foo, 'bar', :baz, 'quux', :metasyntactic, 'variable', :delta, 'charlie', :width, 'quite wide' ]
           actual   = [ :foo, 'bar', :baz, 'quux', :metasyntactic, 'variable', :delta, 'tango'  , :width, 'very wide'  ]
 
-          expected_diff = dedent(<<-'EOD')
+          expected_diff = dedent(<<-"EOD")
             |
             |
-            |@@ -5,7 +5,7 @@
+            |@@ #{::Diff::LCS::VERSION.to_f > 1.5 ? "-5,6 +5,6" : "-5,7 +5,7"} @@
             |  :metasyntactic,
             |  "variable",
             |  :delta,
@@ -307,7 +307,7 @@ module RSpec
               |
             EOD
 
-            expected_diff.gsub!('=>',' => ') if RUBY_VERSION.to_f > 3.3
+            expected_diff.gsub!(/:(\w+)=>/,'\1: ') if RUBY_VERSION.to_f > 3.3
 
             diff = differ.diff(expected,actual)
             expect(diff).to be_diffed_as(expected_diff)
@@ -425,9 +425,9 @@ module RSpec
           expected = "this is:\n  one string"
           actual   = "this is:\n  another string"
 
-          expected_diff = dedent(<<-'EOD')
+          expected_diff = dedent(<<-"EOD")
             |
-            |@@ -1,3 +1,3 @@
+            |@@ #{one_line_header(3)} @@
             | this is:
             |-  another string
             |+  one string
